Keyword detection
=================

.. _markers:

Introduction
------------
The keyword (markers) module allows you to specify words and phrases to detect. For example, you may detect the presence of reasoning using the following
list of markers: ['because', 'in my opinion', 'however'].

Usage
-----

To use the module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.markers.function(to_use)

or:

.. code-block:: console

    >>> from coast_core import markers
    >>> markers.function(to_use)

Functions
---------
.. automodule:: coast_core.markers
    :members:
    :undoc-members:
    :show-inheritance:
